@@ -1,16 +1,5 @@
 /*
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Sébastien Deronne <sebastien.deronne@gmail.com>
  */
@@ -216,7 +205,7 @@ main(int argc, char* argv[])
             /* Setting applications */
             const auto maxLoad = HtPhy::GetDataRate(i,
                                                     channelBonding ? 40 : 20,
-                                                    shortGuardInterval ? 400 : 800,
+                                                    NanoSeconds(shortGuardInterval ? 400 : 800),
                                                     nStreams);
             ApplicationContainer serverApp;
             if (udp)
