@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2008 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -117,7 +106,7 @@ inline Ptr<const AttributeAccessor> MakeAccessorHelper(T1 a1, T2 a2);
  *  Implementation of the templates declared above.
  ***************************************************************/
 
-#include "type-traits.h"
+#include <type_traits>
 
 namespace ns3
 {
@@ -133,7 +122,7 @@ template <typename T>
 struct AccessorTrait
 {
     /** The non-const, non reference type. */
-    typedef typename TypeTraits<typename TypeTraits<T>::ReferencedType>::NonConstType Result;
+    using Result = std::remove_cvref_t<T>;
 };
 
 /**
