@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2005,2006 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  *          Stefano Avallone <stavallo@unina.it>
@@ -23,6 +12,7 @@
 
 #include "attribute-helper.h"
 #include "attribute.h"
+#include "demangle.h"
 #include "fatal-error.h"
 #include "ptr.h"
 #include "simple-ref-count.h"
@@ -99,12 +89,6 @@ class CallbackImplBase : public SimpleRefCount<CallbackImplBase>
     virtual std::string GetTypeid() const = 0;
 
   protected:
-    /**
-     * \param [in] mangled The mangled string
-     * \return The demangled form of mangled
-     */
-    static std::string Demangle(const std::string& mangled);
-
     /**
      * Helper to get the C++ typeid as a string.
      *
