@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2008 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -466,7 +455,7 @@ class CommandLine
 
     /**
      * \ingroup commandline
-     *\brief An argument Item assigning to POD
+     * \brief An argument Item assigning to POD
      */
     template <typename T>
     class UserItem : public Item
@@ -672,8 +661,9 @@ class CommandLine
 
 }; // class CommandLine
 
-/** \ingroup commandline
- *  \defgroup commandlinehelper Helpers to specialize UserItem
+/**
+ * \ingroup commandline
+ * \defgroup commandlinehelper Helpers to specialize UserItem
  */
 /**
  * \ingroup commandlinehelper
