@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2008 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -92,7 +81,14 @@
  * \param msg Optional message to add to the compiler warning.
  *
  */
-#define NS_DEPRECATED(msg) [[deprecated(msg)]]
+#define NS_DEPRECATED(msg) /** \deprecated msg */ [[deprecated(msg)]]
+
+/**
+ * \ingroup deprecation
+ * \def NS_DEPRECATED_3_43
+ * Tag for things deprecated in version ns-3.43.
+ */
+#define NS_DEPRECATED_3_43(msg) NS_DEPRECATED("Deprecated in ns-3.43: " msg)
 
 /**
  * \ingroup deprecation
