@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2006 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -26,6 +15,8 @@
 #include <cmath>
 #include <iostream>
 
+#if defined(INT64X64_USE_CAIRO) && !defined(PYTHON_SCAN)
+
 // Include directly to allow optimizations within this compilation unit.
 extern "C"
 {
@@ -235,3 +226,5 @@ int64x64_t::Invert(const uint64_t v)
 }
 
 } // namespace ns3
+
+#endif /* INT64X64_CAIRO_H */
