@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2005,2006 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -840,13 +829,6 @@ typedef void (*Time)(Time oldValue, Time newValue);
 
 } // namespace TracedValueCallback
 
-/**
- * Force static initialization order of Time in each compilation unit.
- * This is internal to the Time implementation.
- * \relates Time
- */
-static bool g_TimeStaticInit [[maybe_unused]] = Time::StaticInit();
-
 /**
  * Equality operator for Time.
  * \param [in] lhs The first value
@@ -1414,9 +1396,9 @@ ATTRIBUTE_VALUE_DEFINE(Time);
 ATTRIBUTE_ACCESSOR_DEFINE(Time);
 
 /**
- *  \ingroup attribute_time
- *  Helper to make a Time checker with bounded range.
- *  Both limits are inclusive
+ * \ingroup attribute_Time
+ * Helper to make a Time checker with bounded range.
+ * Both limits are inclusive
  *
  * \param [in] min Minimum allowed value.
  * \param [in] max Maximum allowed value.
@@ -1425,7 +1407,7 @@ ATTRIBUTE_ACCESSOR_DEFINE(Time);
 Ptr<const AttributeChecker> MakeTimeChecker(const Time min, const Time max);
 
 /**
- * \ingroup attribute_time
+ * \ingroup attribute_Time
  * Helper to make an unbounded Time checker.
  *
  * \return The AttributeChecker
@@ -1437,7 +1419,7 @@ MakeTimeChecker()
 }
 
 /**
- * \ingroup attribute_time
+ * \ingroup attribute_Time
  * Helper to make a Time checker with a lower bound.
  *
  * \param [in] min Minimum allowed value.
@@ -1490,6 +1472,27 @@ class TimeWithUnit
  */
 TYPENAMEGET_DEFINE(Time);
 
+/**
+ * \ingroup time
+ *
+ * \brief Helper class to force static initialization
+ * of Time in each compilation unit, ensuring it is
+ * initialized before usage.
+ * This is internal to the Time implementation.
+ * \relates Time
+ */
+class TimeInitializationHelper
+{
+  public:
+    /** Default constructor calls Time::StaticInit */
+    TimeInitializationHelper()
+    {
+        Time::StaticInit();
+    }
+};
+
+static TimeInitializationHelper g_timeInitHelper; ///< Instance of Time static initialization helper
+
 } // namespace ns3
 
 #endif /* TIME_H */
