@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2008 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
@@ -248,12 +237,12 @@ ObjectBase::SetAttributeFailSafe(std::string name, const AttributeValue& value)
 }
 
 void
-ObjectBase::GetAttribute(std::string name, AttributeValue& value) const
+ObjectBase::GetAttribute(std::string name, AttributeValue& value, bool permissive) const
 {
     NS_LOG_FUNCTION(this << name << &value);
     TypeId::AttributeInformation info;
     TypeId tid = GetInstanceTypeId();
-    if (!tid.LookupAttributeByName(name, &info))
+    if (!tid.LookupAttributeByName(name, &info, permissive))
     {
         NS_FATAL_ERROR(
             "Attribute name=" << name << " does not exist for this object: tid=" << tid.GetName());
