@@ -2,18 +2,7 @@
  * Copyright (c) 2006 Georgia Tech Research Corporation
  * Copyright (c) 2011 Mathieu Lacage
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Rajib Bhattacharjea<raj.b@gatech.edu>
  *          Hadi Arbabi<marbabi@cs.odu.edu>
@@ -862,6 +851,19 @@ class WeibullRandomVariable : public RandomVariableStream
      */
     double GetBound() const;
 
+    /**
+     * \brief Returns the mean value for the Weibull distribution returned by this RNG stream.
+     * \return The mean value for the Weibull distribution returned by this RNG stream.
+     */
+    double GetMean() const;
+
+    /**
+     * \copydoc GetMean()
+     * \param [in] scale Scale parameter for the Weibull distribution.
+     * \param [in] shape Shape parameter for the Weibull distribution.
+     */
+    static double GetMean(double scale, double shape);
+
     /**
      * \copydoc GetValue()
      * \param [in] scale Scale parameter for the Weibull distribution.
@@ -2271,6 +2273,234 @@ class BernoulliRandomVariable : public RandomVariableStream
 
 }; // class BernoulliRandomVariable
 
+/**
+ * \ingroup randomvariable
+ * \brief The laplacian distribution Random Number Generator (RNG).
+ *
+ * This class supports the creation of objects that return random numbers
+ * from a fixed laplacian distribution.
+ *
+ * The probability density function of a laplacian variable
+ * is defined as:
+ *
+ *   \f[
+ *      P(x; \mu, \beta) dx = \frac{1}{2 \beta} e^{\frac{- \abs{x - \mu}}{\beta}} dx
+ *   \f]
+ *
+ * where \f$\mu\f$ is the \c Location configurable attribute and \f$\beta\f$
+ * is the \c Scale configurable attribute.  This distribution has mean \f$\mu\f$
+ * and variance \f$ \sigma^2 = 2 \beta^2 \f$.
+ *
+ * The laplacian RNG value \f$x\f$ is generated by
+ *
+ *   \f[
+ *      x = \mu - \beta sgn(u) \log(1 - 2 \abs{u})
+ *   \f]
+ *
+ * where \f$u\f$ is a uniform random variable on [-0.5,0.5).
+ *
+ * \par Bounded Distribution
+ *
+ * The Laplacian distribution can be bounded symmetrically about the mean by
+ * the \c Bound parameter, \f$b\f$, _i.e._ its values are confined to the interval
+ * \f$[\mu - b, \mu + b]\f$.  This preserves the mean but decreases the variance.
+ */
+class LaplacianRandomVariable : public RandomVariableStream
+{
+  public:
+    /**
+     * \brief Register this type.
+     * \return The object TypeId.
+     */
+    static TypeId GetTypeId();
+
+    /**
+     * \brief Creates an unbounded laplacian distribution RNG with the default
+     * values for the location and the scale.
+     */
+    LaplacianRandomVariable();
+
+    /**
+     * \brief Get the configured location value of this RNG.
+     *
+     * \return The configured location value.
+     */
+    double GetLocation() const;
+
+    /**
+     * \brief Get the configured scale value of this RNG.
+     *
+     * \return The configured scale value.
+     */
+    double GetScale() const;
+
+    /**
+     * \brief Get the configured bound of this RNG.
+     * \return The bound.
+     */
+    double GetBound() const;
+
+    /**
+     * \copydoc GetValue()
+     * \param [in] location location value of the laplacian distribution.
+     * \param [in] scale scale value of the laplacian distribution.
+     * \param [in] bound bound on values returned.
+     */
+    double GetValue(double location, double scale, double bound);
+
+    /** \copydoc GetValue(double,double,double) */
+    uint32_t GetInteger(uint32_t location, uint32_t scale, uint32_t bound);
+
+    // Inherited
+    double GetValue() override;
+    using RandomVariableStream::GetInteger;
+
+    /**
+     * \brief Returns the variance value for the laplacian distribution returned by this RNG stream.
+     * \return The variance value for the laplacian distribution returned by this RNG stream.
+     */
+    double GetVariance() const;
+
+    /**
+     * \copydoc GetVariance()
+     * \param [in] scale scale value of the laplacian distribution.
+     */
+    static double GetVariance(double scale);
+
+  private:
+    /** The location value of the laplacian distribution. */
+    double m_location;
+
+    /** The scale value of the laplacian distribution. */
+    double m_scale;
+
+    /** The bound on values that can be returned by this RNG stream. */
+    double m_bound;
+
+}; // class LaplacianRandomVariable
+
+/**
+ * \ingroup randomvariable
+ * \brief The Largest Extreme Value distribution Random Number Generator (RNG).
+ *
+ * This class supports the creation of objects that return random numbers from a fixed Largest
+ * Extreme Value distribution. This corresponds to the type-I Generalized Extreme Value
+ * distribution, also known as Gumbel distribution
+ * (https://en.wikipedia.org/wiki/Gumbel_distribution).
+ *
+ * The probability density function of a Largest Extreme Value variable
+ * is defined as:
+ *
+ *   \f[
+ *      P(x; \mu, \beta) dx = \frac{1}{\beta} e^{-(z+ e^{-z})} dx, \quad z = \frac{x - \mu}{\beta}
+ *   \f]
+ *
+ * where \f$\mu\f$ is the \c Location configurable attribute and \f$\beta\f$
+ * is the \c Scale configurable attribute.
+ *
+ * The Largest Extreme Value RNG value \f$x\f$ is generated by
+ *
+ *   \f[
+ *      x = \mu - \beta \log(-\log(u))
+ *   \f]
+ *
+ * where \f$u\f$ is a uniform random variable on [0,1).
+ *
+ * The mean of the distribution is:
+ *
+ *   \f[
+ *      E = \mu + y \beta
+ *   \f]
+ *
+ * where \f$y\f$ is the Euler-Mascheroni constant.
+ *
+ * The variance of the distribution is
+ *
+ *   \f[
+ *      \sigma^2 = 6 \pi^2 \beta^2
+ *   \f]
+ */
+class LargestExtremeValueRandomVariable : public RandomVariableStream
+{
+  public:
+    /**
+     * \brief Register this type.
+     * \return The object TypeId.
+     */
+    static TypeId GetTypeId();
+
+    /**
+     * \brief Creates a Largest Extreme Value distribution RNG with the default
+     * values for the location and the scale.
+     */
+    LargestExtremeValueRandomVariable();
+
+    /**
+     * \brief Get the configured location value of this RNG.
+     *
+     * \return The configured location value.
+     */
+    double GetLocation() const;
+
+    /**
+     * \brief Get the configured scale value of this RNG.
+     *
+     * \return The configured scale value.
+     */
+    double GetScale() const;
+
+    /**
+     * \copydoc GetValue()
+     * \param [in] location location value of the Largest Extreme Value distribution.
+     * \param [in] scale scale value of the Largest Extreme Value distribution.
+     */
+    double GetValue(double location, double scale);
+
+    /** \copydoc GetValue(double,double) */
+    uint32_t GetInteger(uint32_t location, uint32_t scale);
+
+    // Inherited
+    double GetValue() override;
+    using RandomVariableStream::GetInteger;
+
+    /**
+     * \brief Returns the mean value for the Largest Extreme Value distribution returned by this RNG
+     * stream.
+     * \return The mean value for the Largest Extreme Value distribution returned by this
+     * RNG stream.
+     */
+    double GetMean() const;
+
+    /**
+     * \copydoc GetMean()
+     * \param [in] location location value of the Largest Extreme Value distribution.
+     * \param [in] scale scale value of the Largest Extreme Value distribution.
+     */
+    static double GetMean(double location, double scale);
+
+    /**
+     * \brief Returns the variance value for the Largest Extreme Value distribution returned by this
+     * RNG stream.
+     * \return The variance value for the Largest Extreme Value distribution returned by
+     * this RNG stream.
+     */
+    double GetVariance() const;
+
+    /**
+     * \copydoc GetVariance()
+     * \param [in] scale scale value of the Largest Extreme Value distribution.
+     */
+    static double GetVariance(double scale);
+
+  private:
+    /** The location value of the Largest Extreme Value distribution. */
+    double m_location;
+
+    /** The scale value of the Largest Extreme Value distribution. */
+    double m_scale;
+
+}; // class LargestExtremeValueRandomVariable
+
 } // namespace ns3
 
 #endif /* RANDOM_VARIABLE_STREAM_H */
