@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2009 University of Washington
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "test.h"
@@ -22,6 +11,7 @@
 #include "config.h"
 #include "des-metrics.h"
 #include "log.h"
+#include "rng-seed-manager.h"
 #include "singleton.h"
 #include "system-path.h"
 
@@ -357,6 +347,7 @@ TestCase::Run(TestRunnerImpl* runner)
     m_result->clock.Start();
     for (auto i = m_children.begin(); i != m_children.end(); ++i)
     {
+        RngSeedManager::ResetNextStreamIndex();
         TestCase* test = *i;
         test->Run(runner);
         if (IsFailed())
