@@ -1,24 +1,14 @@
 /*
  * Copyright (c) 2007 INRIA
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  */
 
 #ifndef TYPE_TRAITS_H
 #define TYPE_TRAITS_H
 
+#include "deprecated.h"
 #include "ptr.h"
 
 /**
@@ -36,7 +26,7 @@ namespace ns3
  *  \tparam T \deduced The type to inspect.
  */
 template <typename T>
-struct TypeTraits
+struct NS_DEPRECATED_3_43("Use functions provided by #include <type_traits>") TypeTraits
 {
   private:
     /** Null value type traits. */
