@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2009-12 University of Washington
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * This file is based on rng-test-suite.cc.
  *
@@ -29,6 +18,7 @@
 #include "ns3/shuffle.h"
 #include "ns3/string.h"
 #include "ns3/test.h"
+#include "ns3/uinteger.h"
 
 #include <cmath>
 #include <ctime>
@@ -140,6 +130,25 @@ class TestCaseBase : public TestCase
         return valueMean;
     }
 
+    /**
+     * Compute the variance of a random variable.
+     * \param [in] rng The random variable to sample.
+     * \param [in] average The previously calculated average value.
+     * \returns The variance of \c N_MEASUREMENTS samples.
+     */
+    double Variance(Ptr<RandomVariableStream> rng, double average) const
+    {
+        NS_LOG_FUNCTION(this << rng);
+        auto sum = 0.0;
+        for (uint32_t i = 0; i < N_MEASUREMENTS; ++i)
+        {
+            const auto value = rng->GetValue();
+            sum += std::pow(value - average, 2);
+        }
+        const auto valueVariance = sum / N_MEASUREMENTS;
+        return valueVariance;
+    }
+
     /** A factory base class to create new instances of a random variable. */
     class RngGeneratorBase
     {
@@ -1242,12 +1251,12 @@ WeibullTestCase::DoRun()
     SetTestSuiteSeed();
 
     auto generator = RngGenerator<WeibullRandomVariable>();
-    double sum = ChiSquaredsAverage(&generator, N_RUNS);
-    double maxStatistic = gsl_cdf_chisq_Qinv(0.05, N_BINS);
+    const auto sum = ChiSquaredsAverage(&generator, N_RUNS);
+    const auto maxStatistic = gsl_cdf_chisq_Qinv(0.05, N_BINS);
     NS_TEST_ASSERT_MSG_LT(sum, maxStatistic, "Chi-squared statistic out of range");
 
-    double scale = 5.0;
-    double shape = 1.0;
+    const auto scale = 5.0;
+    const auto shape = 1.0;
 
     // Create the RNG with the specified range.
     Ptr<WeibullRandomVariable> x = CreateObject<WeibullRandomVariable>();
@@ -1255,7 +1264,7 @@ WeibullTestCase::DoRun()
     x->SetAttribute("Shape", DoubleValue(shape));
 
     // Calculate the mean of these values.
-    double valueMean = Average(x);
+    const auto measuredMean = Average(x);
 
     // The expected value for the mean of the values returned by a
     // Weibull distributed random variable is
@@ -1279,13 +1288,17 @@ WeibullTestCase::DoRun()
     //
     //     E[value]  =  scale  .
     //
-    double expectedMean = scale;
+    const auto expectedMean = scale;
+
+    // Test calculated and expected mean values are identical.
+    const auto valueMean = x->GetMean();
+    NS_TEST_ASSERT_MSG_EQ(valueMean, expectedMean, "Wrong calculated mean value.");
 
     // Test that values have approximately the right mean value.
-    NS_TEST_ASSERT_MSG_EQ_TOL(valueMean,
+    NS_TEST_ASSERT_MSG_EQ_TOL(measuredMean,
                               expectedMean,
                               expectedMean * TOLERANCE,
-                              "Wrong mean value.");
+                              "Wrong measured mean value.");
 }
 
 /**
@@ -2938,6 +2951,142 @@ ShuffleElementsTest::DoRun()
                           "Expected vector {4, 1, 9, 3, 2, 7}");
 }
 
+/**
+ * \ingroup rng-tests
+ * Test case for laplacian distribution random variable stream generator
+ */
+class LaplacianTestCase : public TestCaseBase
+{
+  public:
+    LaplacianTestCase();
+
+  private:
+    void DoRun() override;
+
+    /**
+     * Tolerance for testing rng values against expectation,
+     * as a fraction of mean value.
+     */
+    static constexpr double TOLERANCE{1e-2};
+};
+
+LaplacianTestCase::LaplacianTestCase()
+    : TestCaseBase("Laplacian Random Variable Stream Generator")
+{
+}
+
+void
+LaplacianTestCase::DoRun()
+{
+    NS_LOG_FUNCTION(this);
+    SetTestSuiteSeed();
+
+    double mu = -5.0;
+    double scale = 4.0;
+    double bound = 20.0;
+
+    // Create unbounded RNG with the specified range.
+    auto x1 = CreateObject<LaplacianRandomVariable>();
+    x1->SetAttribute("Location", DoubleValue(mu));
+    x1->SetAttribute("Scale", DoubleValue(scale));
+
+    // Calculate the mean of these values.
+    auto valueMean = Average(x1);
+
+    // Calculate the variance of these values.
+    auto valueVariance = Variance(x1, valueMean);
+
+    // Test that values have approximately the right mean value.
+    const auto expectedMean = mu;
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueMean, expectedMean, TOLERANCE, "Wrong mean value.");
+
+    // Test that values have approximately the right variance value.
+    const auto expectedVariance = LaplacianRandomVariable::GetVariance(scale);
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueVariance,
+                              expectedVariance,
+                              TOLERANCE * expectedVariance,
+                              "Wrong variance value.");
+
+    // Create bounded RNG with the specified range.
+    auto x2 = CreateObject<LaplacianRandomVariable>();
+    x2->SetAttribute("Location", DoubleValue(mu));
+    x2->SetAttribute("Scale", DoubleValue(scale));
+    x2->SetAttribute("Bound", DoubleValue(bound));
+
+    // Calculate the mean of these values.
+    valueMean = Average(x2);
+
+    // Test that values have approximately the right mean value.
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueMean, expectedMean, TOLERANCE, "Wrong mean value.");
+
+    // Check that only the correct values are returned
+    const auto lowerBound = mu - bound;
+    const auto upperBound = mu + bound;
+    for (uint32_t i = 0; i < N_MEASUREMENTS; ++i)
+    {
+        const auto value = x2->GetValue();
+        NS_TEST_EXPECT_MSG_EQ((value >= lowerBound) || (value <= upperBound),
+                              true,
+                              "Value not in expected boundaries.");
+    }
+}
+
+/**
+ * \ingroup rng-tests
+ * Test case for largest extreme value distribution random variable stream generator
+ */
+class LargestExtremeValueTestCase : public TestCaseBase
+{
+  public:
+    LargestExtremeValueTestCase();
+
+  private:
+    void DoRun() override;
+
+    /**
+     * Tolerance for testing rng values against expectation,
+     * as a fraction of mean value.
+     */
+    static constexpr double TOLERANCE{1e-2};
+};
+
+LargestExtremeValueTestCase::LargestExtremeValueTestCase()
+    : TestCaseBase("Largest Extreme Value Random Variable Stream Generator")
+{
+}
+
+void
+LargestExtremeValueTestCase::DoRun()
+{
+    NS_LOG_FUNCTION(this);
+    SetTestSuiteSeed();
+
+    double mu = 2.0;
+    double scale = 1.0;
+
+    // Create RNG with the specified range.
+    auto x = CreateObject<LargestExtremeValueRandomVariable>();
+    x->SetAttribute("Location", DoubleValue(mu));
+    x->SetAttribute("Scale", DoubleValue(scale));
+
+    // Calculate the mean of these values.
+    auto valueMean = Average(x);
+
+    // Calculate the variance of these values.
+    auto valueVariance = Variance(x, valueMean);
+
+    // Test that values have approximately the right mean value.
+    const auto expectedMean = LargestExtremeValueRandomVariable::GetMean(mu, scale);
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueMean, expectedMean, TOLERANCE, "Wrong mean value.");
+
+    // Test that values have approximately the right variance value.
+    const auto expectedVariance = LargestExtremeValueRandomVariable::GetVariance(scale);
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueVariance,
+                              expectedVariance,
+                              TOLERANCE * expectedVariance,
+                              "Wrong variance value.");
+}
+
 /**
  * \ingroup rng-tests
  * RandomVariableStream test suite, covering all random number variable
@@ -2995,6 +3144,8 @@ RandomVariableSuite::RandomVariableSuite()
     AddTestCase(new BinomialTestCase);
     AddTestCase(new BinomialAntitheticTestCase);
     AddTestCase(new ShuffleElementsTest);
+    AddTestCase(new LaplacianTestCase);
+    AddTestCase(new LargestExtremeValueTestCase);
 }
 
 static RandomVariableSuite randomVariableSuite; //!< Static variable for test initialization
