@@ -1,22 +1,12 @@
 /*
  * Copyright (c) 2009 University of Washington
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "ns3/test.h"
 #include "ns3/type-traits.h"
+#include "ns3/warnings.h"
 
 /**
  * \file
@@ -59,6 +49,12 @@ TypeTraitsTestCase::TypeTraitsTestCase()
 void
 TypeTraitsTestCase::DoRun()
 {
+    // NS_DEPRECATED_3_43
+    // The TypeTraits struct has been deprecated in ns-3.43.
+    // While the struct isn't removed, the deprecation warnings must be silenced.
+    // Once the struct is removed, this test suite should be deleted.
+    NS_WARNING_PUSH_DEPRECATED;
+
     NS_TEST_ASSERT_MSG_EQ(TypeTraits<void (TypeTraitsTestCase::*)()>::IsPointerToMember,
                           1,
                           "Check pointer to member function ()");
@@ -79,6 +75,8 @@ TypeTraitsTestCase::DoRun()
         TypeTraits<void (TypeTraitsTestCase::*)(int) const>::PointerToMemberTraits::nArgs,
         1,
         "Check number of arguments for pointer to member function (int) const");
+
+    NS_WARNING_POP;
 }
 
 /**
