@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2011 Yufei Cheng
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Yufei Cheng   <yfcheng@ittc.ku.edu>
  *
@@ -630,16 +619,16 @@ class DsrTestSuite : public TestSuite
 {
   public:
     DsrTestSuite()
-        : TestSuite("routing-dsr", UNIT)
+        : TestSuite("routing-dsr", Type::UNIT)
     {
-        AddTestCase(new DsrFsHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrRreqHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrRrepHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrSRHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrRerrHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrAckReqHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrAckHeaderTest, TestCase::QUICK);
-        AddTestCase(new DsrCacheEntryTest, TestCase::QUICK);
-        AddTestCase(new DsrSendBuffTest, TestCase::QUICK);
+        AddTestCase(new DsrFsHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrRreqHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrRrepHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrSRHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrRerrHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrAckReqHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrAckHeaderTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrCacheEntryTest, TestCase::Duration::QUICK);
+        AddTestCase(new DsrSendBuffTest, TestCase::Duration::QUICK);
     }
 } g_dsrTestSuite;
