@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2010 Andrea Sacco
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Andrea Sacco <andrea.sacco85@gmail.com>
  */
@@ -36,7 +25,8 @@ NS_OBJECT_ENSURE_REGISTERED(SimpleDeviceEnergyModel);
 TypeId
 SimpleDeviceEnergyModel::GetTypeId()
 {
-    static TypeId tid = TypeId("ns3::SimpleDeviceEnergyModel")
+    static TypeId tid = TypeId("ns3::energy::SimpleDeviceEnergyModel")
+                            .AddDeprecatedName("ns3::SimpleDeviceEnergyModel")
                             .SetParent<DeviceEnergyModel>()
                             .SetGroupName("Energy")
                             .AddConstructor<SimpleDeviceEnergyModel>()
