@@ -18,4 +18,6 @@ cpp_examples = [
 #     (example_name, do_run).
 #
 # See test.py for more information.
-python_examples = []
+python_examples = [
+    ("generic-battery-discharge-example.py", "True"),
+]
