@@ -1,18 +1,7 @@
 /*
  * Copyright (c) University of Washington
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "creator-utils.h"
@@ -113,7 +102,7 @@ SendSocket(const char* path, int fd, const int magic_number)
     // an "ancillary element" but the msghdr uses the control message termimology
     // so we call it "control."
     //
-    size_t msg_size = sizeof(int);
+    constexpr size_t msg_size = sizeof(int);
     char control[CMSG_SPACE(msg_size)];
 
     //
