@@ -1,18 +1,7 @@
 //
 // Copyright (c) 2009 INESC Porto
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License version 2 as
-// published by the Free Software Foundation;
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// SPDX-License-Identifier: GPL-2.0-only
 //
 // Author: Gustavo J. A. M. Carneiro  <gjc@inescporto.pt> <gjcarneiro@gmail.com>
 //
@@ -89,6 +78,10 @@ class FlowMonitor : public Object
         /// Contains the last measured delay of a packet
         /// It is stored to measure the packet's Jitter
         Time lastDelay;
+        /// Contains the largest measured delay of a received packet
+        Time maxDelay;
+        /// Contains the smallest measured delay of a received packet
+        Time minDelay;
 
         /// Total number of transmitted bytes for the flow
         uint64_t txBytes;
