@@ -2,18 +2,7 @@
  * Copyright (c) 2010-2015 Adrian Sai-wah Tam
  * Copyright (c) 2016 Natale Patriciello <natale.patriciello@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Original author: Adrian Sai-wah Tam <adrian.sw.tam@gmail.com>
  */
@@ -174,6 +163,7 @@ TcpTxBuffer::SetHeadSequence(const SequenceNumber32& seq)
 
     // if you change the head with data already sent, something bad will happen
     NS_ASSERT(m_sentList.empty());
+    m_sackSeen = false;
     m_highestSack = std::make_pair(m_sentList.end(), SequenceNumber32(0));
 }
 
@@ -767,6 +757,7 @@ TcpTxBuffer::DiscardUpTo(const SequenceNumber32& seq, const Callback<void, TcpTx
 
     if (m_highestSack.second <= m_firstByteSeq)
     {
+        m_sackSeen = false;
         m_highestSack = std::make_pair(m_sentList.end(), SequenceNumber32(0));
     }
 
@@ -831,6 +822,7 @@ TcpTxBuffer::Update(const TcpOptionSack::SackList& list, const Callback<void, Tc
                     if (m_highestSack.first == m_sentList.end() ||
                         m_highestSack.second <= beginOfCurrentPacket + pktSize)
                     {
+                        m_sackSeen = true;
                         m_highestSack = std::make_pair(item_it, beginOfCurrentPacket);
                     }
 
@@ -983,7 +975,8 @@ TcpTxBuffer::NextSeg(SequenceNumber32* seq, SequenceNumber32* seqHigh, bool isRe
         item = *it;
 
         // Condition 1.a , 1.b , and 1.c
-        if (!item->m_retrans && !item->m_sacked)
+        if (!item->m_retrans && !item->m_sacked &&
+            ((m_sackSeen && item->m_startSeq < m_highestSack.second) || !m_sackSeen))
         {
             if (item->m_lost)
             {
@@ -1213,6 +1206,7 @@ TcpTxBuffer::ResetRenoSack()
     }
 
     m_highestSack = std::make_pair(m_sentList.end(), SequenceNumber32(0));
+    m_sackSeen = false;
 }
 
 void
@@ -1241,6 +1235,7 @@ TcpTxBuffer::ResetSentList()
     m_lostOut = 0;
     m_retrans = 0;
     m_sackedOut = 0;
+    m_sackSeen = false;
     m_highestSack = std::make_pair(m_sentList.end(), SequenceNumber32(0));
 }
 
@@ -1273,6 +1268,7 @@ TcpTxBuffer::SetSentListLost(bool resetSack)
     {
         m_sackedOut = 0;
         m_lostOut = m_sentSize;
+        m_sackSeen = false;
         m_highestSack = std::make_pair(m_sentList.end(), SequenceNumber32(0));
     }
     else
@@ -1400,6 +1396,7 @@ TcpTxBuffer::AddRenoSack()
     {
         (*it)->m_sacked = true;
         m_sackedOut += (*it)->m_packet->GetSize();
+        m_sackSeen = true;
         m_highestSack = std::make_pair(it, (*it)->m_startSeq);
         NS_LOG_INFO("Added a Reno SACK, status: " << *this);
     }
