@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2019 Ritsumeikan University, Shiga, Japan.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Alberto Gallegos Ramonet <ramonet@fc.ritsumei.ac.jp>
  */
@@ -664,12 +653,12 @@ class IcmpTestSuite : public TestSuite
 };
 
 IcmpTestSuite::IcmpTestSuite()
-    : TestSuite("icmp", UNIT)
+    : TestSuite("icmp", Type::UNIT)
 {
-    AddTestCase(new IcmpEchoReplyTestCase, TestCase::QUICK);
-    AddTestCase(new IcmpTimeExceedTestCase, TestCase::QUICK);
-    AddTestCase(new IcmpV6EchoReplyTestCase, TestCase::QUICK);
-    AddTestCase(new IcmpV6TimeExceedTestCase, TestCase::QUICK);
+    AddTestCase(new IcmpEchoReplyTestCase, TestCase::Duration::QUICK);
+    AddTestCase(new IcmpTimeExceedTestCase, TestCase::Duration::QUICK);
+    AddTestCase(new IcmpV6EchoReplyTestCase, TestCase::Duration::QUICK);
+    AddTestCase(new IcmpV6TimeExceedTestCase, TestCase::Duration::QUICK);
 }
 
 static IcmpTestSuite icmpTestSuite; //!< Static variable for test initialization
