@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2022 ZHIHENG DONG
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Zhiheng Dong <dzh2077@gmail.com>
  */
@@ -1230,15 +1219,15 @@ class NeighborCacheTestSuite : public TestSuite
 {
   public:
     NeighborCacheTestSuite()
-        : TestSuite("neighbor-cache", UNIT)
+        : TestSuite("neighbor-cache", Type::UNIT)
     {
-        AddTestCase(new DynamicNeighborCacheTest, TestCase::QUICK);
-        AddTestCase(new ChannelTest, TestCase::QUICK);
-        AddTestCase(new NetDeviceContainerTest, TestCase::QUICK);
-        AddTestCase(new InterfaceContainerTest, TestCase::QUICK);
-        AddTestCase(new FlushTest, TestCase::QUICK);
-        AddTestCase(new DuplicateTest, TestCase::QUICK);
-        AddTestCase(new DynamicPartialTest, TestCase::QUICK);
+        AddTestCase(new DynamicNeighborCacheTest, TestCase::Duration::QUICK);
+        AddTestCase(new ChannelTest, TestCase::Duration::QUICK);
+        AddTestCase(new NetDeviceContainerTest, TestCase::Duration::QUICK);
+        AddTestCase(new InterfaceContainerTest, TestCase::Duration::QUICK);
+        AddTestCase(new FlushTest, TestCase::Duration::QUICK);
+        AddTestCase(new DuplicateTest, TestCase::Duration::QUICK);
+        AddTestCase(new DynamicPartialTest, TestCase::Duration::QUICK);
     }
 };
 
