@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2023 Tokushima University, Japan.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  *  Author: Alberto Gallegos Ramonet <alramonet@is.tokushima-u.ac.jp>
  */
@@ -33,7 +22,10 @@ NS_OBJECT_ENSURE_REGISTERED(LrWpanMacBase);
 TypeId
 LrWpanMacBase::GetTypeId()
 {
-    static TypeId tid = TypeId("ns3::LrWpanMacBase").SetParent<Object>().SetGroupName("LrWpan");
+    static TypeId tid = TypeId("ns3::lrwpan::LrWpanMacBase")
+                            .AddDeprecatedName("ns3::LrWpanMacBase")
+                            .SetParent<Object>()
+                            .SetGroupName("LrWpan");
     return tid;
 }
 
