@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2011 The Boeing Company
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author:
  *  Gary Pei <guangyu.pei@boeing.com>
@@ -147,7 +136,8 @@ TypeId
 LrWpanPhy::GetTypeId()
 {
     static TypeId tid =
-        TypeId("ns3::LrWpanPhy")
+        TypeId("ns3::lrwpan::LrWpanPhy")
+            .AddDeprecatedName("ns3::LrWpanPhy")
             .SetParent<SpectrumPhy>()
             .SetGroupName("LrWpan")
             .AddConstructor<LrWpanPhy>()
@@ -166,7 +156,7 @@ LrWpanPhy::GetTypeId()
             .AddTraceSource("TrxState",
                             "The state of the transceiver",
                             MakeTraceSourceAccessor(&LrWpanPhy::m_trxStateLogger),
-                            "ns3::LrWpanPhy::StateTracedCallback")
+                            "ns3::lrwpan::LrWpanPhy::StateTracedCallback")
             .AddTraceSource("PhyTxBegin",
                             "Trace source indicating a packet has "
                             "begun transmitting over the channel medium",
