@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2022 Tokushima University, Japan
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Alberto Gallegos Ramonet <alramonet@is.tokushima-u.ac.jp>
  */
@@ -454,10 +443,13 @@ TestActiveScanPanDescriptors::DoRun()
                                    params);
 
     // PAN coordinator N2 (PAN 7) is set to channel 14 in non-beacon mode but answer to beacon
-    // requests. The second coordinator includes a beacon payload of 25 bytes using the
+    // requests. The second coordinator includes a beacon payload of 2 bytes using the
     // MLME-SET.request primitive.
     Ptr<MacPibAttributes> pibAttribute = Create<MacPibAttributes>();
-    pibAttribute->macBeaconPayload = Create<Packet>(25);
+    std::vector<uint8_t> payload;
+    payload.emplace_back(1);
+    payload.emplace_back(2);
+    pibAttribute->macBeaconPayload = payload;
     coord2NetDevice->GetMac()->MlmeSetRequest(MacPibAttributeIdentifier::macBeaconPayload,
                                               pibAttribute);
 
@@ -519,8 +511,8 @@ TestActiveScanPanDescriptors::DoRun()
                               " be less than Coordinator 1 (PAN 5).");
 
         NS_TEST_EXPECT_MSG_EQ(g_beaconPayloadSize,
-                              25,
-                              "Error, Beacon Payload not received or incorrect size (25 bytes)");
+                              2,
+                              "Error, Beacon Payload not received or incorrect size (2 bytes)");
     }
 
     Simulator::Destroy();
