@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2018 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Manuel Requena <manuel.requena@cttc.es>
  */
@@ -127,9 +116,9 @@ class GtpcHeader : public Header
     /// FTEID structure
     struct Fteid_t
     {
-        InterfaceType_t interfaceType; //!< Interface type
-        Ipv4Address addr;              //!< IPv4 address
-        uint32_t teid;                 //!< TEID
+        InterfaceType_t interfaceType{}; //!< Interface type
+        Ipv4Address addr;                //!< IPv4 address
+        uint32_t teid;                   //!< TEID
     };
 
     /// Message Type enumeration
