@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2011-2013 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Marco Miozzo <marco.miozzo@cttc.es>
  *         Nicola Baldo <nbaldo@cttc.es>
@@ -167,6 +156,11 @@ LenaDataPhyErrorModelTestCase::DoRun()
     Config::SetDefault("ns3::RrFfMacScheduler::HarqEnabled", BooleanValue(false));
     Config::SetGlobal("RngRun", UintegerValue(m_rngRun));
 
+    Config::SetDefault("ns3::RadioBearerStatsCalculator::DlRlcOutputFilename",
+                       StringValue(CreateTempDirFilename("DlRlcStats.txt")));
+    Config::SetDefault("ns3::RadioBearerStatsCalculator::UlRlcOutputFilename",
+                       StringValue(CreateTempDirFilename("UlRlcStats.txt")));
+
     // Disable Uplink Power Control
     Config::SetDefault("ns3::LteUePhy::EnableUplinkPowerControl", BooleanValue(false));
 
