@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2014 Piotr Gawlowicz
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Piotr Gawlowicz <gawlowicz.p@gmail.com>
  *
@@ -53,19 +42,20 @@ NS_LOG_COMPONENT_DEFINE("LteUplinkPowerControlTest");
  */
 
 LteUplinkPowerControlTestSuite::LteUplinkPowerControlTestSuite()
-    : TestSuite("lte-uplink-power-control", SYSTEM)
+    : TestSuite("lte-uplink-power-control", Type::SYSTEM)
 {
     //  LogLevel logLevel = (LogLevel)(LOG_PREFIX_FUNC | LOG_PREFIX_TIME | LOG_LEVEL_DEBUG);
     //  LogComponentEnable ("LteUplinkPowerControlTest", logLevel);
     NS_LOG_INFO("Creating LteUplinkPowerControlTestSuite");
 
-    AddTestCase(new LteUplinkOpenLoopPowerControlTestCase("OpenLoopTest1"), TestCase::QUICK);
+    AddTestCase(new LteUplinkOpenLoopPowerControlTestCase("OpenLoopTest1"),
+                TestCase::Duration::QUICK);
     AddTestCase(
         new LteUplinkClosedLoopPowerControlAbsoluteModeTestCase("ClosedLoopAbsoluteModeTest1"),
-        TestCase::QUICK);
+        TestCase::Duration::QUICK);
     AddTestCase(new LteUplinkClosedLoopPowerControlAccumulatedModeTestCase(
                     "ClosedLoopAccumulatedModeTest1"),
-                TestCase::QUICK);
+                TestCase::Duration::QUICK);
 }
 
 /**
