@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2013 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors:
  *   Nicola Baldo <nbaldo@cttc.es>
@@ -749,7 +738,7 @@ class LteX2HandoverMeasuresTestSuite : public TestSuite
 };
 
 LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
-    : TestSuite("lte-x2-handover-measures", SYSTEM)
+    : TestSuite("lte-x2-handover-measures", Type::SYSTEM)
 {
     Time checkInterval = Seconds(1);
 
@@ -789,7 +778,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
                                                       1,
                                                       1,
@@ -800,7 +789,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::QUICK);
+                    TestCase::Duration::QUICK);
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
                                                       1,
                                                       2,
@@ -811,7 +800,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       0,
@@ -822,7 +811,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       1,
@@ -833,7 +822,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       2,
@@ -844,7 +833,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::EXTENSIVE);
+                    TestCase::Duration::EXTENSIVE);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       0,
@@ -855,7 +844,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::EXTENSIVE);
+                    TestCase::Duration::EXTENSIVE);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       1,
@@ -866,7 +855,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       2,
@@ -877,7 +866,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
     }
 
     sched = "ns3::RrFfMacScheduler";
@@ -894,7 +883,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::EXTENSIVE);
+                    TestCase::Duration::EXTENSIVE);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       0,
@@ -905,7 +894,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       0,
@@ -916,7 +905,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
     }
 
     ho = "ns3::A3RsrpHandoverAlgorithm";
@@ -934,7 +923,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::EXTENSIVE);
+                    TestCase::Duration::EXTENSIVE);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       0,
@@ -945,7 +934,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       0,
@@ -956,7 +945,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
     }
 
     sched = "ns3::RrFfMacScheduler";
@@ -973,7 +962,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::QUICK);
+                    TestCase::Duration::QUICK);
         AddTestCase(new LteX2HandoverMeasuresTestCase(3,
                                                       1,
                                                       0,
@@ -984,7 +973,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::TAKES_FOREVER);
+                    TestCase::Duration::TAKES_FOREVER);
         AddTestCase(new LteX2HandoverMeasuresTestCase(4,
                                                       1,
                                                       0,
@@ -995,7 +984,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
                                                       ho,
                                                       true,
                                                       useIdealRrc),
-                    TestCase::EXTENSIVE);
+                    TestCase::Duration::EXTENSIVE);
     }
 
 } // end of LteX2HandoverMeasuresTestSuite ()
