@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2008,2009 IITP RAS
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Authors: Kirill Andreev <andreev@iitp.ru>
  *          Aleksey Kovalenko <kovalenko@iitp.ru>
@@ -71,7 +60,7 @@ class HwmpTag : public Tag
      * Get the TTL value
      * \returns the TTL
      */
-    uint8_t GetTtl();
+    uint8_t GetTtl() const;
     /**
      * Set the metric value
      * \param metric the metric
@@ -81,7 +70,7 @@ class HwmpTag : public Tag
      * Get the metric value
      * \returns the metric
      */
-    uint32_t GetMetric();
+    uint32_t GetMetric() const;
     /**
      * Set sequence number
      * \param seqno the sequence number
@@ -91,7 +80,7 @@ class HwmpTag : public Tag
      * Get the sequence number
      * \returns the sequence number
      */
-    uint32_t GetSeqno();
+    uint32_t GetSeqno() const;
     /// Decrement TTL
     void DecrementTtl();
 
