@@ -1,18 +1,7 @@
 /*
  * Copyright (c) 2014 University of Washington
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation;
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * SPDX-License-Identifier: GPL-2.0-only
  *
  * Author: Benjamin Cizdziel <ben.cizdziel@gmail.com>
  */
@@ -183,7 +172,7 @@ class RandCartAroundGeoTestSuite : public TestSuite
 };
 
 RandCartAroundGeoTestSuite::RandCartAroundGeoTestSuite()
-    : TestSuite("rand-cart-around-geo", UNIT)
+    : TestSuite("rand-cart-around-geo", Type::UNIT)
 {
     NS_LOG_INFO("creating RandCartAroundGeoTestSuite");
     Ptr<UniformRandomVariable> uniRand = CreateObject<UniformRandomVariable>();
@@ -201,7 +190,7 @@ RandCartAroundGeoTestSuite::RandCartAroundGeoTestSuite()
                                                           50, // 50 points generated
                                                           maxDistFromOrigin,
                                                           uniRand),
-                            TestCase::QUICK);
+                            TestCase::Duration::QUICK);
             }
         }
     }
